@@ -345,14 +345,14 @@ def game_rink_map(data, good_team = None, title = None, size = None, strengths =
 
             if team == good_team:
 
-                legend_elements = [Line2D([0], [0], color = colors_dict['SHOT'], marker = 'o',
-                                    markerfacecolor = colors[team]['GOAL'], label = 'GOAL', markersize = 45),
+                legend_elements = [Line2D([0], [0], color = colors[team]['SHOT'], marker = 'o',
+                                    markerfacecolor = colors[team]['GOAL'], label = 'GOAL', markersize = 20),
                                     
-                                    Line2D([0], [0], marker='o', color = colors_dict['SHOT'], label= 'SHOT',
-                                        markerfacecolor = colors[team]['SHOT'], markersize = 16),
+                                    Line2D([0], [0], marker='o', color = colors[team]['SHOT'], label= 'SHOT',
+                                        markerfacecolor = colors[team]['SHOT'], markersize = 20),
 
-                                   Line2D([0], [0], marker='o', color = colors_dict['MISS'], label= 'MISS',
-                                    markerfacecolor = colors[team]['MISS'], markersize = 16)]
+                                   Line2D([0], [0], marker='o', color = colors[team]['MISS'], label= 'MISS',
+                                    markerfacecolor = colors[team]['MISS'], markersize = 20)]
 
                 legend = ax.legend(handles = legend_elements, loc="lower center", ncol=3, title = f'{team}', fontsize = 14,
                                     title_fontsize = 16, facecolor = 'white', framealpha = 1,
@@ -360,14 +360,14 @@ def game_rink_map(data, good_team = None, title = None, size = None, strengths =
   
             if team == bad_team:
 
-                legend_elements = [Line2D([0], [0], color = colors_dict['SHOT'], marker = 'o',
-                                    markerfacecolor = colors[team]['GOAL'], label = 'GOAL', markersize = 45),
+                legend_elements = [Line2D([0], [0], color = colors[team]['SHOT'], marker = 'o',
+                                    markerfacecolor = colors[team]['GOAL'], label = 'GOAL', markersize = 20),
                                     
-                                    Line2D([0], [0], marker='o', color = colors_dict['SHOT'], label= 'SHOT',
-                                        markerfacecolor = colors[team]['SHOT'], markersize = 45),
+                                    Line2D([0], [0], marker='o', color = colors[team]['SHOT'], label= 'SHOT',
+                                        markerfacecolor = colors[team]['SHOT'], markersize = 20),
 
-                                   Line2D([0], [0], marker='o', color = colors_dict['MISS'], label= 'MISS',
-                                    markerfacecolor = colors[team]['MISS'], markersize = 45)]
+                                   Line2D([0], [0], marker='o', color = colors[team]['MISS'], label= 'MISS',
+                                    markerfacecolor = colors[team]['MISS'], markersize = 20)]
 
                 legend = ax.legend(handles = legend_elements, loc="upper center", ncol=3, title = f'{team}', fontsize = 14,
                                     title_fontsize = 16, facecolor = 'white', framealpha = 1,
